==> apigateway-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/BasePathMapping.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * This resource creates a base path that clients who call your API must use in the invocation URL.
 * 
 * In most cases, you will probably want to use
 * `DomainName.addBasePathMapping()` to define mappings.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:22:40.378Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.BasePathMapping")
public class BasePathMapping extends software.amazon.awscdk.core.Resource {

    protected BasePathMapping(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BasePathMapping(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BasePathMapping(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.BasePathMappingProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }
}

==> apigateway-1.10.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/BasePathMapping.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * This resource creates a base path that clients who call your API must use in the invocation URL.
 * 
 * In most cases, you will probably want to use
 * `DomainName.addBasePathMapping()` to define mappings.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-30T08:39:26.047Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.BasePathMapping")
public class BasePathMapping extends software.amazon.awscdk.core.Resource {

    protected BasePathMapping(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BasePathMapping(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BasePathMapping(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.apigateway.BasePathMappingProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }
}
